@@ -1,7 +1,7 @@
 package Getopt::Long::EvenLess;
 
 our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -190,7 +190,7 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.02 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2015-06-17.
+This document describes version 0.03 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2015-06-17.
 
 =head1 DESCRIPTION
 
@@ -229,29 +229,29 @@ object as its first argument.
 
 =item * does not support hashref as first argument
 
-=item * does not support bool/negation (so you have to declare both C<foo> and C<no-foo> manually)
+=item * does not support bool/negation (no C<foo!>, so you have to declare both C<foo> and C<no-foo> manually)
 
 =back
 
 Sample startup overhead benchmark:
 
-                           Rate      run_gl     load_gl run_gl_evenless load_gl_evenless run_gl_less load_gl_less   perl
- run_gl           75.66+-0.35/s          --       -0.3%          -66.6%           -67.5%      -68.3%       -69.5% -88.5%
- load_gl          75.89+-0.14/s  0.31+-0.5%          --          -66.5%           -67.4%      -68.2%       -69.4% -88.4%
- run_gl_evenless   226.4+-1.1/s   199.2+-2% 198.3+-1.5%              --            -2.7%       -5.3%        -8.6% -65.5%
- load_gl_evenless  232.7+-1.7/s 207.6+-2.7% 206.6+-2.4%      2.8+-0.91%               --       -2.6%        -6.1% -64.5%
- run_gl_less         239+-2.6/s 215.9+-3.7% 214.9+-3.4%       5.6+-1.2%        2.7+-1.3%          --        -3.5% -63.6%
- load_gl_less      247.7+-1.4/s 227.4+-2.4% 226.4+-1.9%     9.44+-0.81%         6.45+-1%   3.7+-1.3%           -- -62.2%
- perl                656+-2.4/s 767.1+-5.1% 764.4+-3.6%     189.8+-1.7%      181.9+-2.4% 174.5+-3.1%  164.8+-1.8%     --
+                            Rate      run_gl     load_gl load_gl_evenless run_gl_less run_gl_evenless load_gl_less   perl
+ run_gl            75.92+-0.34/s          --       -0.3%           -67.6%      -68.0%          -68.2%       -69.1% -88.3%
+ load_gl           76.11+-0.26/s 0.25+-0.56%          --           -67.5%      -67.9%          -68.1%       -69.0% -88.3%
+ load_gl_evenless   234.2+-1.2/s 208.5+-2.1% 207.8+-1.9%               --       -1.3%           -1.8%        -4.5% -63.8%
+ run_gl_less        237.3+-1.1/s   212.6+-2% 211.8+-1.8%      1.31+-0.69%          --           -0.5%        -3.3% -63.4%
+ run_gl_evenless  238.57+-0.57/s 214.2+-1.6% 213.5+-1.3%      1.85+-0.57% 0.53+-0.52%              --        -2.8% -63.2%
+ load_gl_less         245.4+-1/s   223.2+-2% 222.4+-1.7%      4.75+-0.69% 3.39+-0.64%      2.85+-0.5%           -- -62.1%
+ perl                 647.8+-1/s 753.3+-4.1% 751.2+-3.2%      176.6+-1.5%   173+-1.3%   171.55+-0.78%    164+-1.2%     --
  
  Average times:
-   perl            :     1.5244ms
-   load_gl_less    :     4.0371ms
-   run_gl_less     :     4.1841ms
-   load_gl_evenless:     4.2974ms
-   run_gl_evenless :     4.4170ms
-   load_gl         :    13.1770ms
-   run_gl          :    13.2170ms
+   perl            :     1.5437ms
+   load_gl_less    :     4.0750ms
+   run_gl_evenless :     4.1916ms
+   run_gl_less     :     4.2141ms
+   load_gl_evenless:     4.2699ms
+   load_gl         :    13.1389ms
+   run_gl          :    13.1718ms
 
 =for Pod::Coverage .+
 
